==> huaweicloudsdkgaussdb-3.1.134-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/reset_database_password_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResetDatabasePasswordRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'users': 'list[ResetDatabasePassword]'
    }

    attribute_map = {
        'users': 'users'
    }

    def __init__(self, users=None):
        """ResetDatabasePasswordRequest

        The model defined in huaweicloud sdk

        :param users: 准备修改密码的数据库用户列表，列表最大长度为50。
        :type users: list[:class:`huaweicloudsdkgaussdb.v3.ResetDatabasePassword`]
        """
        
        

        self._users = None
        self.discriminator = None

        self.users = users

    @property
    def users(self):
        """Gets the users of this ResetDatabasePasswordRequest.

        准备修改密码的数据库用户列表，列表最大长度为50。

        :return: The users of this ResetDatabasePasswordRequest.
        :rtype: list[:class:`huaweicloudsdkgaussdb.v3.ResetDatabasePassword`]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this ResetDatabasePasswordRequest.

        准备修改密码的数据库用户列表，列表最大长度为50。

        :param users: The users of this ResetDatabasePasswordRequest.
        :type users: list[:class:`huaweicloudsdkgaussdb.v3.ResetDatabasePassword`]
        """
        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetDatabasePasswordRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/reset_database_password_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResetDatabasePasswordRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'users': 'list[ResetDatabasePassword]'
    }

    attribute_map = {
        'users': 'users'
    }

    def __init__(self, users=None):
        r"""ResetDatabasePasswordRequest

        The model defined in huaweicloud sdk

        :param users: 准备修改密码的数据库用户列表，列表最大长度为50。
        :type users: list[:class:`huaweicloudsdkgaussdb.v3.ResetDatabasePassword`]
        """
        
        

        self._users = None
        self.discriminator = None

        self.users = users

    @property
    def users(self):
        r"""Gets the users of this ResetDatabasePasswordRequest.

        准备修改密码的数据库用户列表，列表最大长度为50。

        :return: The users of this ResetDatabasePasswordRequest.
        :rtype: list[:class:`huaweicloudsdkgaussdb.v3.ResetDatabasePassword`]
        """
        return self._users

    @users.setter
    def users(self, users):
        r"""Sets the users of this ResetDatabasePasswordRequest.

        准备修改密码的数据库用户列表，列表最大长度为50。

        :param users: The users of this ResetDatabasePasswordRequest.
        :type users: list[:class:`huaweicloudsdkgaussdb.v3.ResetDatabasePassword`]
        """
        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetDatabasePasswordRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
